#
# spec file for package SAPHanaSR
#
# Copyright (c) 2013-2014 SUSE Linux Products GmbH, Nuernberg, Germany.
# Copyright (c) 2014-2016 SUSE Linux GmbH, Nuernberg, Germany.
# Copyright (c) 2017-2024 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/

%define crmscr_path /usr/share/crmsh/scripts/

Name:           SAPHanaSR
License:        GPL-2.0
Group:          Productivity/Clustering/HA
AutoReqProv:    on
Summary:        Resource agents to control the HANA database in system replication setup
Version:        0.162.4
Release:        150000.4.44.1
Url:            http://scn.sap.com/community/hana-in-memory/blog/2014/04/04/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution

BuildArch:      noarch
Source0:        %{name}-%{version}.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       pacemaker > 1.1.1
Requires:       resource-agents
Requires:       perl

Requires:       crmsh
Requires:       crmsh-scripts >= 2.2.0
Requires:       python3
Requires:       /usr/bin/xmllint
BuildRequires:  resource-agents
BuildRequires:  crmsh
BuildRequires:  crmsh-scripts

%package doc
Summary:        Setup Guide for SAPHanaSR
Group:          Productivity/Clustering/HA

%description
The resource agents SAPHana and SAPHanaTopology are responsible for controlling
a SAP HANA Database which is running in system replication (SR) configuration.

For SAP HANA Databases in System Replication only the described or referenced scenarios in
the README file of this package are supported. For any scenario not matching the scenarios
named or referenced in the README file please contact SUSE at SAP LinuxLab (sap-lab@suse.de).

The following SCN blog gives a first overwiew about running SAP HANA in System Replication with
our resource agents:
http://scn.sap.com/community/hana-in-memory/blog/2014/04/04/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution

Authors:
--------
    Fabian Herschel
    Lars Pinne
    Angela Briel


%description doc
This subpackage includes the Setup Guide for getting SAP HANA system replication under cluster control.


%prep
%setup -n %{name}-%{version}
gzip man/*

%build

%install
mkdir -p %{buildroot}/usr/sbin
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}/usr/share/%{name}/icons
mkdir -p %{buildroot}/usr/share/%{name}/tests
mkdir -p %{buildroot}/usr/share/%{name}/samples
mkdir -p %{buildroot}/usr/lib/ocf/resource.d/suse
mkdir -p %{buildroot}/usr/lib/%{name}
mkdir -p %{buildroot}%{_mandir}/man7
mkdir -p %{buildroot}%{_mandir}/man8

# resource agents
install -m 0755 ra/* %{buildroot}/usr/lib/ocf/resource.d/suse/

# HA/DR hook provider
install -m 0644 srHook/SAPHanaSR.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susTkOver.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susCostOpt.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susChkSrv.py %{buildroot}/usr/share/%{name}/
install -m 0444 srHook/global.ini %{buildroot}/usr/share/%{name}/samples
install -m 0444 srHook/global.ini_SAPHanaSR %{buildroot}/usr/share/%{name}/samples
install -m 0444 srHook/global.ini_sus* %{buildroot}/usr/share/%{name}/samples

# icons for SAPHanaSR-monitor
install -m 0444 icons/* %{buildroot}/usr/share/%{name}/icons

# documentation
install -m 0444 doc/LICENSE %{buildroot}/%{_docdir}/%{name}
install -m 0444 doc/README %{buildroot}/%{_docdir}/%{name}
install -m 0444 doc/SAPHanaSR-Setup-Guide.pdf %{buildroot}/%{_docdir}/%{name}

# manual pages
install -m 0444 man/*.7.gz %{buildroot}%{_mandir}/man7
install -m 0444 man/*.8.gz %{buildroot}%{_mandir}/man8

# auxiliary Perl library and test scripts
#install -m 0555 test/SAPHanaSR-testDriver %{buildroot}/usr/share/%{name}/tests
install -m 0555 test/SAPHanaSR-monitor %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-showAttr %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-replay-archive %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-filter %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-hookHelper %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-manageProvider %{buildroot}/usr/sbin
install -m 0444 test/SAPHanaSRTools.pm %{buildroot}/usr/lib/%{name}
install -m 0755 test/SAPHanaSR-upgrade-to-angi-demo %{buildroot}/usr/share/%{name}/samples
install -D -m 0644 wizard/hawk2/saphanasr.yaml %{buildroot}%{crmscr_path}/saphanasr/main.yml
install -D -m 0644 wizard/hawk2/saphanasr_su_po.yaml %{buildroot}%{crmscr_path}/saphanasr-su-po/main.yml
install -D -m 0644 wizard/hawk2/saphanasr_su_co.yaml %{buildroot}%{crmscr_path}/saphanasr-su-co/main.yml


%files
%defattr(-,root,root)
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/suse
/usr/lib/ocf/resource.d/suse/*
/usr/share/%{name}
%dir /usr/lib/%{name}
/usr/lib/%{name}/SAPHanaSRTools.pm
/usr/sbin/SAPHanaSR-monitor
/usr/sbin/SAPHanaSR-showAttr
/usr/sbin/SAPHanaSR-replay-archive
/usr/sbin/SAPHanaSR-filter
/usr/sbin/SAPHanaSR-hookHelper
/usr/sbin/SAPHanaSR-manageProvider

%dir %{crmscr_path}/saphanasr/
%dir %{crmscr_path}/saphanasr-su-po/
%dir %{crmscr_path}/saphanasr-su-co/
%{crmscr_path}/saphanasr/main.yml
%{crmscr_path}/saphanasr-su-po/main.yml
%{crmscr_path}/saphanasr-su-co/main.yml
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/LICENSE
%doc %{_mandir}/man7/*
%doc %{_mandir}/man8/*

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}/SAPHanaSR-Setup-Guide.pdf

%changelog
* Tue May  7 2024 abriel@suse.com
- Version bump to 0.162.4
  * unify global.ini examples
  * add demo script SAPHanaSR-upgrade-to-angi-demo
  * update man pages:
    SAPHanaSR_basic_cluster.7
    SAPHanaSR_maintenance_examples.7
    SAPHanaSR_upgrade_to_angi.7
    SAPHanaSR-manageProvider.8
    SAPHanaSR-upgrade-to-angi-demo.8
    SAPHanaSR.py.7
* Mon Jan 29 2024 abriel@suse.com
- Version bump to 0.162.3
  * Fix the hexdump log for empty node states
  * catch monitor calls for non-cloned resources and report them as
    unsupported instead of 'command not found'
    (bsc#1218333)
  * fix scope of variable 'site' to be global
    (bsc#1219194)
  * susChkSrv.py - relocate function logTimestamp()
  * update man pages:
    SAPHanaSR.7
    ocf_suse_SAPHana.7
    SAPHanaSR_maintenance_examples.7
    SAPHanaSR.py.7
    SAPHanaSR-showAttr.8
* Thu Nov  2 2023 abriel@suse.com
- Version bump to 0.162.2
  * inside SAPHanaSR-hookHelper use the full path for the cibadmin
    command to support non root users in special user environments
    (bsc#1216484)
  * if the SAPHanaSR.py hook has successfully reported a SR event
    to the cluster a still existing fall-back state file will be
    removed to prevent an override of an already reported
    SR state.
    (bsc#1215693)
  * improve supportability by providing the current process ID of
    the RA, which is logged in the RA outputs, to HANA tracefiles
    too.
    This allows a mapping of the SAP related command invocations
    from the RA and the HANA executions which might have a delay
    in between.
    (bsc#1214613)
  * avoid explicid and implicid usage of /tmp filesystem to keep
    the SAPHanaSR resource agents working even in situations with
    /tmp filesystem full.
    (bsc#1210728)
  * update man pages:
    SAPHanaSR.7
    SAPHanaSR_basic_cluster.7
    SAPHanaSR_maintenance_examples.7
    ocf_suse_SAPHana.7
    ocf_suse_SAPHanaTopology.7
    susCostOpt.py.7
    SAPHanaSR-monitor.8
    SAPHanaSR-showAttr.8
  * add improvements from SAP to the RA scripts, part II
    (jsc#PED-1739, jsc#PED-2608)
* Tue Jan 24 2023 abriel@suse.com
- Version bump to 0.162.1
  * fix for SAPHanaTopology failing with error code 1
    (OCF_ERR_GENERIC) during a normal stop action
    (bsc#1207466)
  * set srhook attribute to PRIM during a probe so that we do not
    need to wait for the first srConnectionChanged() to set the
    attribute
    (bsc#1205535)
* Wed Nov 23 2022 abriel@suse.com
- Version bump to 0.162.0
  * add improvements from SAP to the RA scripts regarding the
    handling of the SAP tools 'HDB version', 'HDBSettings.sh' and
    'pycd' and the SAPHana log filter handling
    (jsc#PED-1739, jsc#PED-2608)
  * fix for SAPHanaSR-monitor reporting "LPA status of one node is
    missing"
    (bsc#1192963, bsc#1203973)
  * SAPHanaSRTools.pm: shows terminate node attribute too
- remove patch:
    0001-bsc-1192963.patch
* Thu Oct  6 2022 varkoly@suse.com
- SAPHanaSR-monitor not reporting correctly
  (bsc#1192963)
  add patch:
    0001-bsc-1192963.patch
* Tue Aug 23 2022 abriel@suse.com
- Version bump to 0.161.1_BF
- add the required 'xmllint' to the package
  (bsc#1201945)
- changes to the demote_clone function of the resource agent:
  if the role is '1:P' (topology agent run into timeouts) the
  function fail with rc=1, to get the managed resource stopped
  changes to the stop_clone function of the topology agent:
  call landscapeHostConfiguration.py and set the roles as they were
  reported. If the command timed out, set the role to '1:P' and
  return 1 to get the node fenced.
  The used timeout for the landscapeHostConfiguration.py call can
  be configured by the cluster action timeout, if needed. It will
  be 50%% of the action timeout or the minimum of 300s.
  (bsc#1198127)
- add new HA/DR provider hook susChkSrv
  (jsc#PED-1241, jsc#PED-1240)
- add new tool SAPHanaSR-manageProvider to show, add and delete
  HA/DR provider sections in the global.ini of SAP HANA.
- update suse icon to new branding
* Wed Jun  1 2022 abriel@suse.com
- Version bump to 0.160.1
- fix HANA_CALL function to support MCOS environments again
  (bsc#1198780)
- fix SAPHanaSR-replay-archive to handle hb_report archives again
  (bsc#1198897)
- add HANA_CALL_TIMEOUT parameter back to the resource agents and
  read the setting from the cluster configuration, if available.
  Defaults to '60'.
  Related to github issue#36
- add new HA/DR provider hook susTkOver
  (jsc#SLE-16347)
- add new hook script for SAP HANA System Replication Scale-Up Cost
  Optimized Scenario.
  (jsc#SLE-18613)
- add a new instance parameter 'REMOVE_SAP_SOCKETS'.
  It is an optional parameter and defaults to 'true'. Now you can
  control, if the RA should remove the unix domain sockets related
  to sapstartsrv before (re-)start sapstartsrv or if it should try
  to adjust the permissions and ownership of these files instead.
* Tue Nov 23 2021 abriel@suse.com
- Version bump to 0.155.0
- Add systemd support for the resource agent to interact with the
  new SAP unit files for sapstartsrv.
  As the new version of the SAP Startup Framework will use systemd
  unit files to control the sapstartsrv process instead of the
  previous used SysV init script, we need to adapt the handling of
  sapstartsrv inside the resource agents to support both ways.
  (bsc#1189530, bsc#1189531)
- The resource start and stop timeout is now configurable by
  increasing the timeout for the action 'start' and/or 'stop'.
  We will use 95%% of this action timeouts to calculate the new
  resource start and stop timeout for the 'WaitforStarted' and
  'WaitforStopped' functions. If the new, calculated timeout value
  is less than '3600', it will be set to '3600', so that we do not
  decrease this timeout by accident
  (bsc#1182545)
- change promotion scoring during maintenance procedure to prevent
  that both sides have an equal promotion scoring after refresh
  which might result in a critical promotion of the secondary.
  (bsc#1174557)
- update of man page SAPHanaSR.py.7 - correct the supported HANA
  version.
  (bsc#1182201)
- if the $hdbState command fails to retrieve the current state of
  the System Replication, the resource agent now uses the
  system_replication/actual_mode attribute (if available) from the
  global.ini file as a fallback.
  This should prevent some confusing and misleading log messages
  during a takeover and solves the problem of a not working
  takeover back (after a successful first takeover)
  (bsc#1181765)
- add dedicated logging of HANA_CALL problems. So it will be now
  possible to identify, if the called hana command or the needed
  su command throws the error and for further hints we log the
  stderr output.
  Additional it is possible to get regular log messages for the
  used commands, their return code and their stderr output by
  enabling the 'debug' mode of the resource agents.
  (bsc#1182774)
* Thu Jul  2 2020 abriel@suse.com
- Version bump to 0.154.1
- log empty site names, but do not generate bad formatted cluster
  attribute name
  (bsc#1173581)
- fix documentation of some parameter defaults
- adjust start/stop/promote/monitor action timeouts to match
  official recommendations
* Thu Nov 21 2019 abriel@suse.com
- restart sapstartsrv service on master nameserver node during
  monitor action, if needed. But NOT during probes.
  (bsc#1157453)
* Fri Nov 15 2019 abriel@suse.com
- Version bump to 0.154.0
- restart sapstartsrv service on master nameserver node
  (bsc#1156150)
* Fri Nov  8 2019 abriel@suse.com
- Version bump to 0.153.3
- The SAPHana resource agent must not down-score a SAP HANA
  Database site, if the landscape status is still 2, which means
  warning.
  Keep high scoring during recovery of the master name server.
  Use a fall-back scoring for the master nameserver nodes, if the
  current roles of the node(s) got lost.
  (bsc#1156067)
- change the shebang line of the HAWK2 templates to python3
  (bsc#1155423)
* Wed Sep 11 2019 abriel@suse.com
- fix typo in a condition statement (bnc#1149829)
* Fri Aug 30 2019 abriel@suse.com
- Version bump to 0.153.2
- rescore the master and fix some log string literals
- Fix bsc#1133866:
  Return $OCF_RUNNING_MASTER (8) instead of $OCF_SUCCESS (0) when
  probing a promoted node.
- If the SAP HANA CALL to 'landscapeHostConfiguration.py' is
  running into a timeout, do a retry of the command. If it still
  fails with a timeout, raise an error but do not set attributes
  to prevent unlogged failovers because of empty or unknown
  attributes.
  (bsc#1134106, bsc#1133024, bsc#1101373)
- Fix bsc#1082974:
  set attribute for remoteNode
- Fix bsc#1139715:
  Using crm-attributes written by a SAP HANA SR provider hook does
  improve the data integrity in special error conditions with
  multiple errors coming in a short time frame.
  Stabilized remote-site detection; SAPHana could now use a site
  specific SR cluster attribute which could be set by a SAP HA/DR
  provider call.
  Add a HA/DR provider hook script, config implementation and man
  page.
  Add parameter "HANA_CALL_TIMEOUT" to the RA configuration
  (SAPHanaTopology and SAPHanaSR) to set a timeout for HANA calls
  like landscapeHostConfiguration.py.
  Implemented "reload" method to allow changing parameters like
  "AUTOMATED_REGISTER"
  Set SWAIT during startup, but only if the attribute is already set
  Set PRIM after promote, but only if the attribute is already set
  The promote function has to set the return code according to the
  checks of the takeover result
  New tool SAPHanaSR-replay-archive, SAPHanaSR-filter and
  SAPHanaSR-showAttr to support SITE attributes
* Fri May 18 2018 imanyugin@suse.com
- Version bump to 0.152.22
- Fix bsc#1091074:
    + Adjust Perl scripts to Perl 5.26.0
    + Remove show_SAPHanaSR_attributes
    + The user is advised to use SAPHanaSR-showAttr instead
- SAPHanaTopology: stricter match for system replication 'mode' in awk
* Wed Jan 31 2018 ro@suse.de
- remove duplicate BuildArch line from specfile
* Mon Nov 20 2017 imanyugin@suse.com
- FATE#323526: adjust HAWK2 Wizards to run on both Python 2 and 3
* Mon Oct 23 2017 imanyugin@suse.com
- Fix bsc#1062267: SAPHanaSR wizard sets IPAddr2 agent's NIC to eth0
* Thu Jul  6 2017 imanyugin@suse.com
- Fix bsc#1045606: update man pages
* Fri Jun  2 2017 imanyugin@suse.com
- Fix bsc#1042154: Scoring race condition between SAPHanaTopology and SAPHana
* Fri May 26 2017 imanyugin@suse.com
- Version bump to 0.152.21
* Wed May  3 2017 imanyugin@suse.com
- Fix bsc#1034685: SAPHanaTopology fails once after updating to 0.152.20
* Wed Feb 15 2017 imanyugin@suse.com
- Version bump to 0.152.20
- Fix bsc#1019117: Fix master scoring of secondary during a takeover
* Tue Dec 20 2016 ilya.manyugin@suse.com
- Version bump to 0.152.19
- Fix bsc#1014397: SAPHanaSR not failing over consistently
- Fix bsc#1008469: SAPHanaSR-monitor reports wrong status colors and error messages
- Add a cluster attribute hana_<SID>_version upon a probe of SAPHanaTopology
- Update man pages
- Change the Setup Guide to contain just the URL to the best practices
- Fix bsc#994753: Tool SAPHanaSR-showAttr fails to read offline cib file correctly
- Fix bsc#1016691: Status file of SAPHanaTopology is not multi instance aware (MCOS)
- Fix bsc#1016936: SAPHanaSR-TestDriver fails to detect the correct status
- Fix bsc#985822: HAWK Wizards are listed as legacy
* Wed Nov  2 2016 imanyugin@suse.com
- Version bump to 0.152.18
- Fix bsc#985474: SAPHanaSR-showAttr shows node ID instead of uname
- Fix bsc#1007825: SAPHanaSR-showAttr fails to show node status
- Fix bsc#1005872: SAPHana Resource Agent handling virtual hostnames
- Fix bsc#1007605: SAPHanaSR no longer ignores DR SR status
* Wed Jun  1 2016 fabian.herschel@suse.com
- bsc#982355 - SAPHanaSR: SAP changed the interface of landscapeHostConfiguration.py beginning with SPS12 rev 120
- bsc#981446 - SAPHanaSR: SAP revokes interface hdbnsutil -sr_state beginning from rev 112.03
* Tue May  3 2016 fabian.herschel@suse.com
- log_attributes are not longer logged to /var/log/fhATTRIBUTES by default
* Fri Apr 29 2016 fabian.herschel@suse.com
- bsc#977644 -  SAPHanaSR: SAP Hana resource with Virtual IP not migrating from master to secondary node correctly
* Tue Nov 24 2015 fabian.herschel@suse.com
- Fix for bsc#954653; SAPHanaSR: Resources SAPHana and SAPHanaTopology not managed correctly by Hawk in SLES12 for SAP
- Use new parameters for hdbnsutil -sr_regsiter for SAP HANA >= SPS110
* Thu Oct  8 2015 fabian.herschel@suse.com
- Fix for bsc#949544; SAPHanaSR needs to handle hanging SAP HANA calls
* Mon Oct  5 2015 fabian.herschel@suse.com
- Fix for bsc#947303; SAPHanaSR: SAPHana resource agent still requires secure store users
* Thu Aug 20 2015 fabian.herschel@suse.com
- Avoid to set local lpt, if accidently the remote host name is empty
* Wed Jul 22 2015 fabian.herschel@suse.com
- Fix for bsc#939039; SAPHanaSR fails to detect remote site name if site names are substring of an other remote site name like SLE and SLEDR
* Tue Jul 14 2015 fabian.herschel@suse.com
- Updated the package version to 0.151 to relfect matching the upstream version
* Mon Jun 29 2015 fabian.herschel@suse.com
- Fix for bsc#935755; SAPHanaSR together with DAA-SAP-Instance does not work as expected
- Fix for bsc#936387; SAPHanaSR fails to work with multi tenant databases
- Fix for bsc#919925; SAPHanaSR: Leaving Node Maintenance stops HANA Resource Agent
* Mon Dec  8 2014 fabian.herschel@suse.com
- Fix for bsc#908861; SAPHanaSR should be tolerant to an additional secondary
  Still only ONE SAPHANA SID in SR per cluster, still two nodes only but
  an additional secondary in a chain (like A=>B->C) could now be ignored
* Tue Nov  4 2014 fabian.herschel@suse.com
- Package version 0.149;
- Fix for bnc#902244; SAPHanaSR fails when hdbnsutil does not return correctly or does report incomplete output
- Fix for bnc#902241; SAPHanaSR fails in cold bootstrap
- Updated Setup-Guide 11/04/2014
* Fri Jun 13 2014 fabian.herschel@suse.com
- Fix for bnc#882474; SAPHanaSR: SAPHanaTopology could now handle broken saphostexec
* Wed Jun  4 2014 fabian.herschel@suse.com
- Package version 0.148; Fate 317181 Resource Agents for SAP HANA System Replication
